@@ -11,7 +11,7 @@ The main atributes are:
 *Class for unidimensional scalar masks*
 
 *Functions*
-    * mask_from_function, mask_from_array.
+    * mask_from_function, mask_from_array
     * slit, double slit
     * two_levels, gray_scale
     * prism, biprism_fresnel, biprism_fresnel_nh
@@ -24,10 +24,10 @@ The main atributes are:
 
 from scipy.interpolate import interp1d
 
-from diffractio import degrees, mm, np, plt, sp, um
-from diffractio.scalar_fields_X import Scalar_field_X
-from diffractio.utils_math import cut_function, fft_convolution1d, nearest2
-from diffractio.utils_optics import roughness_1D
+from . import degrees, np, plt, um
+from .scalar_fields_X import Scalar_field_X
+from .utils_math import cut_function, fft_convolution1d, nearest, nearest2
+from .utils_optics import roughness_1D
 
 
 class Scalar_mask_X(Scalar_field_X):
@@ -37,7 +37,7 @@ class Scalar_mask_X(Scalar_field_X):
         x (numpy.array): linear array with equidistant positions.
             The number of data is preferibly :math:`2^n` .
         wavelength (float): wavelength of the incident field
-        n_background (float): refraction index of backgroudn
+        n_background (float): refraction index of background
         info (str): String with info about the simulation
 
     Attributes:
@@ -167,6 +167,24 @@ class Scalar_mask_X(Scalar_field_X):
         self.u = t * np.exp(1.j * k * (index - 1) * (F2 - F1))
         self.u[t == 0] = 0
 
+    def dots(self, x0):
+        """Generates 1 or several point masks at positions x0
+
+        Parameters:
+            x0 float or np.array: x point or points where mask is 1.
+        """
+        u = np.zeros_like(self.x)
+
+        if type(x0) in (int, float):
+            i_x0, _, _ = nearest(self.x, x0)
+            u[i_x0] = 1
+        else:
+            i_x0s, _, _ = nearest2(self.x, x0)
+            for i_x0 in i_x0s:
+                u[i_x0] = 1
+
+        self.u = u
+
     def slit(self, x0=0, size=100 * um):
         """Slit: 1 inside, 0 outside
 
@@ -206,22 +224,22 @@ class Scalar_mask_X(Scalar_field_X):
 
         return self.u
 
-    def two_levels(self, level1=0, level2=1, xcorte=0):
+    def two_levels(self, level1=0, level2=1, x_edge=0):
         """Divides the image in two levels.
 
         Parameters:
             level1 (float): value of level1
             level2 (float): value of level2
-            xcorte (float): position of separation of levels
+            x_edge (float): position of separation of levels
         """
 
         # Definicion de un primer level de unos
         self.u = level1 * np.ones(self.x.shape)
         # Aquellos points cuyo mayor sea mayor que el value de corte, adquieren
         # el value del level2
-        self.u[self.x > xcorte] = level2
+        self.u[self.x > x_edge] = level2
 
-    def gray_scale(self, num_levels=4, levelMin=0, levelMax=1):
+    def gray_scale(self, num_levels, levelMin=0, levelMax=1):
         """Divides the mask in n, vertical levels.
 
         Parameters:
@@ -271,7 +289,7 @@ class Scalar_mask_X(Scalar_field_X):
             mask (bool): if True radius is applied
         """
 
-        k = 2 * sp.pi / self.wavelength
+        k = 2 * np.pi / self.wavelength
 
         # distance from generatriz to cone axis
         xp = self.x > x0
@@ -282,7 +300,7 @@ class Scalar_mask_X(Scalar_field_X):
         h[xp] = -np.sin(angle) * (self.x[xp] - x0)
         h[xn] = np.sin(angle) * (self.x[xn] - x0)
 
-        u = sp.exp(1.j * (k * h + np.pi))
+        u = np.exp(1.j * (k * h + np.pi))
 
         t = np.ones_like(self.x)
 
@@ -296,10 +314,10 @@ class Scalar_mask_X(Scalar_field_X):
         self.u = u * t
 
     def biprism_fresnel_nh(self,
-                           x0=0 * um,
-                           width=100 * um,
-                           height=5 * um,
-                           n=1.5):
+                           x0,
+                           width,
+                           height,
+                           n):
         """Fresnel biprism, uses height and refraction index.
 
         Parameters:
@@ -331,7 +349,7 @@ class Scalar_mask_X(Scalar_field_X):
         self.u = u * np.exp(1.j * k * (n - 1) * h)
         return h
 
-    def lens(self, x0=0 * um, radius=100 * um, focal=5 * mm, mask=True):
+    def lens(self, x0, focal, radius, mask=True):
         """Transparent lens.
 
         Parameters:
@@ -362,44 +380,56 @@ class Scalar_mask_X(Scalar_field_X):
         h = h / h.max()
         return t * h
 
-    def aspheric(self, c, k, a, n0=1, n1=1.5, x0=0 * um, radius=None):
+    def aspheric(self, x0, c, k, a, n0, n1, radius, mask=True):
         """asferic surface.
 
+        $z = \frac{c r^2}{1+\sqrt{1-(1+k) c^2 r^2 }}+\sum{a_i r^{2i}}$
+
         Parameters:
-            c (float):
-            k (float):
-            a (list):
-            n0 (float): refraction index of first medium
-            n1 (flaot): refraction index of second medium
             x0 (float): position of center
+            c (float): base curvature at vertex, inverse of radius
+            k (float): conic constant
+            a (list): order aspheric coefficients: A4, A6, A8, ...
+            n0 (float): refraction index of first medium
+            n1 (float): refraction index of second medium
             radius (float): radius of aspheric surface
+
+
+        Conic Constant    Surface Type
+        k = 0             spherical
+        k = -1            Paraboloid
+        k < -1            Hyperboloid
+        -1 < k < 0        Ellipsoid
+        k > 0             Oblate eliposid
+
+        References:
+            https://www.edmundoptics.com/knowledge-center/application-notes/optics/all-about-aspheric-lenses/
         """
-        k = 2 * np.pi / self.wavelength
-        t1 = c * (self.x - x0)**2 / (1 - np.sqrt(1 - (1 + k) * c**2 *
-                                                 (self.x - x0)**2))
+
+        s2 = (self.x - x0)**2
+        t1 = c * s2 / (1 + np.sqrt(1 - (1 + k) * c**2 * s2))
 
         t2 = 0
-        for i, ai in enumerate(a):
-            t2 = t2 + ai * self.x**(2 * (1 + i))
+        if a is not None:
+            for i, ai in enumerate(a):
+                t2 = t2 + ai * s2 ** (2 + i)
 
         t = t1 + t2
 
-        # TODO mal los radios
-        if radius in (None, '', 0):
-            mask = 1
+        if mask is True:
+            m1 = np.zeros_like(self.x, dtype=int)
+            ix = (self.x < x0 + radius) & (self.x > x0 - radius)
+            m1[ix] = 1
         else:
-            mask = np.zeros_like(self.x)
-            ix = (self.x - x0 < -radius) & (self.x - x0 > radius)
-            mask[ix] = 1
+            m1 = np.ones_like(self.x, dtype=int)
 
-        plt.figure()
-        plt.plot(self.x, mask)
-
-        self.u = mask * np.exp(1j * k * (n1 - n0) * t)
+        self.u = m1 * np.exp(1j * 2 * np.pi * (n1 - n0) * t / self.wavelength)
+        self.u[m1 == 0] = 0
+        return t
 
     def fresnel_lens(self,
-                     x0=0 * um,
-                     focal=5 * mm,
+                     x0,
+                     focal,
                      kind='amplitude',
                      binary=True,
                      phase=np.pi,
@@ -479,7 +509,7 @@ class Scalar_mask_X(Scalar_field_X):
         self.u = u
         return h_corr
 
-    def dust_different_sizes(self, percentaje, size=0, std=0):
+    def dust_different_sizes(self, percentaje, size, std=0):
         """Mask with dust particles of different sizes.
 
         Parameters:
@@ -559,14 +589,14 @@ class Scalar_mask_X(Scalar_field_X):
 
         return positions, percentaje_real
 
-    def sine_grating(self, period=40 * um, amp_min=0, amp_max=1, x0=0 * um):
+    def sine_grating(self, x0, period, amp_min=0, amp_max=1):
         """Sinusoidal grating
 
         Parameters:
+            x0 (float): shift of grating
             period (float): period of the grating
             amp_min (float): minimum amplitude
             amp_max (float): maximum amplitude
-            x0 (float): shift of grating
         """
         # Definicion de la sinusoidal
         self.u = amp_min + (amp_max - amp_min) * (
@@ -574,12 +604,12 @@ class Scalar_mask_X(Scalar_field_X):
 
         return self.u
 
-    def ronchi_grating(self, period, x0=0 * um, fill_factor=0.5):
+    def ronchi_grating(self, x0, period, fill_factor=0.5):
         """Amplitude binary grating, fill-factor can be defined. It is obtained as a sine_grating that after is binarized. Fill factor is determined as  y0=cos(pi*fill_factor)
 
         Parameters:
-            period (float): period of the grating
             x0 (float): shift of the grating
+            period (float): period of the grating
             fill_factor (float): (0,1) - fill factor of grating
         """
 
@@ -592,37 +622,37 @@ class Scalar_mask_X(Scalar_field_X):
         return t.u
 
     def binary_grating(self,
-                       period=40 * um,
-                       amin=0,
-                       amax=1,
-                       phase=0 * np.pi / 2,
-                       x0=0,
-                       fill_factor=0.5):
+                       x0,
+                       period,
+                       fill_factor,
+                       amin,
+                       amax,
+                       phase):
         """binary grating amplitude and/or phase
 
         Parameters:
+            x0 (float): shift of the grating
             period (float): period of the grating
+            fill_factor (float): (0,1) - fill factor of grating
             amin (float): minimum amplitude
             amax (float): maximum amplitude
             phase (float): phase shift (radians)
-            x0 (float): shift of the grating
-            fill_factor (float): (0,1) - fill factor of grating
         """
 
         t = Scalar_mask_X(self.x, self.wavelength)
-        t.ronchi_grating(period, x0, fill_factor)
+        t.ronchi_grating(period=period, x0=x0, fill_factor=fill_factor)
         self.u = amin + (amax - amin) * t.u
         self.u = self.u * np.exp(1j * phase * t.u)
         return t.u
 
-    def blazed_grating(self, period=40 * um, height=2 * um, n=1.5, x0=0 * um):
+    def blazed_grating(self, x0, period, height, n, ):
         """Phase, blazed grating. The phase shift is determined by heigth and refraction index.
 
         Parameters:
+            x0 (float): shift of the grating
             period (float): period of the grating
             height (float): height of grating
             n (float): refraction index of grating
-            x0 (float): shift of the grating
         """
 
         k = 2 * np.pi / self.wavelength
@@ -891,34 +921,73 @@ class Scalar_mask_X(Scalar_field_X):
 
         return t
 
+    def binary_code_positions(self, x_transitions, start='down', has_draw=True):
+        """
+        Genenerates a binary code, using the positions given in x_transitions
+
+        Parameters:
+            x_transitions (numpy.array): positions where transitions are placed
+            start (str): How the binary code starts:'down' (starts in 0) or 'up' (starts in 1)
+            has_draw (bool): If True, draws the code
+
+        """
+
+        x_transitions = np.sort(x_transitions)
+        x_transitions = np.hstack((self.x[0], x_transitions, self.x[-1]))
+        x_transitions = np.unique(x_transitions)
+
+        t = np.ones_like(self.x)
+
+        i_transitions, _, _ = nearest2(self.x, x_transitions)
+
+        i_transitions = i_transitions.astype(int)
+
+        for i in range(0, len(i_transitions) - 1, 2):
+            i0 = i_transitions[i]
+            i1 = i_transitions[i + 1]
+            t[i0:i1] = 0
+
+        if start == 'up':
+            t = 1 - t
+
+        self.u = t
+
+        if has_draw:
+            plt.figure(figsize=(18, 5))
+            plt.plot(self.x, t)
+            plt.plot(x_transitions, np.ones_like(x_transitions), 'ko')
+            plt.xlim(self.x[0], self.x[-1])
+
+        return t
+
     def binary_code(self,
+                    x0=0 * um,
                     kind='standard',
-                    i0=[1, 1, 0, 0, 1, 0, 1],
-                    bit_width=20 * um,
-                    x0=0 * um):
+                    code=[1, 1, 0, 0, 1, 0, 1],
+                    bit_width=20 * um):
         """Binary code in form of 1's and 0's.
 
         Parameters:
-            kind (str): there are serveral types of IO
+            kind (str): there are serveral types of codes
                 'standard' - normal
                 'abs_fag' -  used in some abs encoders
-            i0 (numpy.array): array with values of i0
-            bit_width (float): size of each data of i0
+            code (numpy.array): array with values of code
+            bit_width (float): size of each data of code
             x0 (float): Initial position
         """
 
         if kind == 'abs_fag':
-            i0_ones = np.ones_like(i0)
-            i0_zeros = np.zeros_like(i0)
-            i0 = np.vstack((i0_zeros, i0_ones, i0, i0_ones)).reshape((-1, ),
-                                                                     order='F')
+            i0_ones = np.ones_like(code)
+            i0_zeros = np.zeros_like(code)
+            code = np.vstack((i0_zeros, i0_ones, code, i0_ones)).reshape((-1, ),
+                                                                         order='F')
             bit_width = bit_width / 4
 
         t = Scalar_mask_X(self.x, self.wavelength)
         t2 = Scalar_mask_X(self.x, self.wavelength)
         t.u = np.zeros(self.x.shape)
 
-        for i0j, j in zip(i0, list(range(len(i0)))):
+        for i0j, j in zip(code, list(range(len(code)))):
             t2.slit(x0 + (j + 0.5) * bit_width, bit_width)
             t.u = t.u + i0j * t2.u
         self.u[-1] = self.u[-2]
