@@ -34,11 +34,11 @@ import numexpr as ne
 import scipy.ndimage as ndimage
 from scipy.interpolate import interp1d
 
-from diffractio import degrees, mm, np, plt, sp, um
-from diffractio.scalar_fields_XZ import Scalar_field_XZ
-from diffractio.scalar_masks_X import Scalar_mask_X
-from diffractio.utils_math import nearest, nearest2
-from diffractio.utils_optics import roughness_1D
+from . import degrees, np, plt, sp, um
+from .scalar_fields_XZ import Scalar_field_XZ
+from .scalar_masks_X import Scalar_mask_X
+from .utils_math import nearest, nearest2
+from .utils_optics import roughness_1D
 
 
 class Scalar_mask_XZ(Scalar_field_XZ):
@@ -49,7 +49,7 @@ class Scalar_mask_XZ(Scalar_field_XZ):
             The number of data is preferibly :math:`2^n` .
         z (numpy.array): linear array wit equidistant positions for z values
         wavelength (float): wavelength of the incident field
-        n_background (float): refraction index of backgroudn
+        n_background (float): refraction index of background
         info (str): String with info about the simulation
 
     Attributes:
@@ -328,7 +328,6 @@ class Scalar_mask_XZ(Scalar_field_XZ):
         """
 
         # Rotacion del square/rectangle
-
         Xrot, Zrot = self.__rotate__(angle, rotation_point)
 
         v_locals = {
@@ -338,6 +337,7 @@ class Scalar_mask_XZ(Scalar_field_XZ):
             'um': um,
             'np': np
         }
+
         v_locals['Xrot'] = Xrot
         v_locals['Zrot'] = Zrot
 
@@ -396,7 +396,7 @@ class Scalar_mask_XZ(Scalar_field_XZ):
 
         # surface detection
         diff1a = np.diff(np.abs(self.n), axis=1)
-        diff1a = np.append(diff1a, np.zeros((len_z, 1)), axis=1)
+        diff1a = np.append(diff1a, np.zeros((len_x, 1)), axis=1)
 
         # cada uno de los lados
         ix_l, iz_l = (diff1a > min_incr).nonzero()
@@ -434,7 +434,7 @@ class Scalar_mask_XZ(Scalar_field_XZ):
             array2=fx2_n,
             x_sides=x_sides,
             angle=0 * degrees,
-            interp_kind='quadratic')
+            interp_kind='linear')
 
         self.surface_detection()  # bordes nuevos
         perfil_nuevo = self.borders
@@ -456,7 +456,7 @@ class Scalar_mask_XZ(Scalar_field_XZ):
         self.n = n
         return n
 
-    def image(self, filename, n_max=1.5, n_min=1, angle=0, invert=False):
+    def image(self, filename, n_max, n_min, angle=0, invert=False):
         """Converts an image file in an xz-refraction index matrix.
         If the image is gray-scale the refraction index is gradual betwee n_min and n_max.
         If the image is color, we get the first Red frame
@@ -501,7 +501,30 @@ class Scalar_mask_XZ(Scalar_field_XZ):
             image = image.max() - image
         self.n = n_min + image * (n_max - n_min)
 
-    def semi_plane(self, r0, refraction_index, angle, rotation_point=None):
+    def dots(self, positions, refraction_index=1):
+        """Generates 1 or several point masks at positions r0
+
+        Parameters:
+            positions (float, float) or (np.array, np.array): (x,z) point or points where mask is 1
+            refraction_index (float): refraction index
+        """
+        x0, z0 = positions
+        n = np.zeros_like(self.X)
+
+        if type(positions[0]) in (int, float):
+            i_x0, _, _ = nearest(self.x, x0)
+            i_z0, _, _ = nearest(self.z, z0)
+            n[i_x0, i_z0] = refraction_index
+        else:
+            i_x0s, _, _ = nearest2(self.x, x0)
+            i_z0s, _, _ = nearest2(self.z, z0)
+            for (i_x0, i_z0) in zip(i_x0s, i_z0s):
+                n[i_x0, i_z0] = refraction_index
+
+        self.n = n
+        return self
+
+    def semi_plane(self, r0, refraction_index, angle=0, rotation_point=None):
         """Inserts a semi-sphere in background (x>x0). If it is something else previous, it is removed.
 
         Parameters:
@@ -593,7 +616,7 @@ class Scalar_mask_XZ(Scalar_field_XZ):
         Fs = [cond1, cond2, cond3, cond4]
 
         ipasa = self.object_by_surfaces(
-            rotation_point, refraction_index, Fs, angle, v_globals={})
+            rotation_point, refraction_index, Fs, angle, v_globals={'np': np})
 
         return ipasa
 
@@ -681,7 +704,7 @@ class Scalar_mask_XZ(Scalar_field_XZ):
                     r0,
                     radius,
                     refraction_index,
-                    angle,
+                    angle=0,
                     rotation_point=None):
         """ Insert a semi_sphere in background.
 
@@ -718,7 +741,7 @@ class Scalar_mask_XZ(Scalar_field_XZ):
                               radius,
                               thickness,
                               refraction_index,
-                              angle,
+                              angle=0,
                               rotation_point=None,
                               mask=0):
         """Insert a plane-convergent lens in background-
@@ -786,7 +809,7 @@ class Scalar_mask_XZ(Scalar_field_XZ):
                         radius,
                         thickness,
                         refraction_index,
-                        angle,
+                        angle=0,
                         rotation_point=None,
                         mask=0):
         """Inserts a convergent lens in background.
@@ -857,7 +880,7 @@ class Scalar_mask_XZ(Scalar_field_XZ):
                              radius,
                              thickness,
                              refraction_index,
-                             angle,
+                             angle=0,
                              rotation_point=None,
                              mask=False):
         """Insert a plane-divergent lens in background.
@@ -922,7 +945,7 @@ class Scalar_mask_XZ(Scalar_field_XZ):
                        radius,
                        thickness,
                        refraction_index,
-                       angle,
+                       angle=0,
                        rotation_point=None,
                        mask=0):
         """Insert a  divergent lens in background.
@@ -1121,7 +1144,7 @@ class Scalar_mask_XZ(Scalar_field_XZ):
               length,
               refraction_index,
               angle_wedge,
-              angle,
+              angle=0,
               rotation_point=None):
         """ Insert a wedge pointing towards the light beam
 
@@ -1152,7 +1175,7 @@ class Scalar_mask_XZ(Scalar_field_XZ):
               length,
               refraction_index,
               angle_prism,
-              angle,
+              angle=0,
               rotation_point=None):
         """Similar to wedge but the use is different. Also the angle is usually different. One of the sides is paralel to x=x0
 
@@ -1181,13 +1204,13 @@ class Scalar_mask_XZ(Scalar_field_XZ):
             rotation_point, refraction_index, Fs, angle, v_globals={})
         return ipasa
 
-    def biprism(self, r0, length, height, refraction_index, angle):
+    def biprism(self, r0, length, height, refraction_index, angle=0):
         """Fresnel biprism.
 
         Parameters:
             r0 (float, float): (x0,z0) Location of the rectangle, for example (0 * um, 20 * um)
             length (float): length of the long part (z direction)
-            length (float): height of biprism
+            height (float): height of biprism
             refraction_index (float, str): refraction index , for example: 1.5 + 1.0j
             angle (float): angle of rotation of the semi-plane, in radians
         """
@@ -1218,17 +1241,17 @@ class Scalar_mask_XZ(Scalar_field_XZ):
             rotation_point, refraction_index, Fs, angle, v_globals={})
         return ipasa
 
-    def ronchi_grating(self, period, fill_factor, length, height, r0, Dx,
+    def ronchi_grating(self, r0, period, fill_factor, length, height, Dx,
                        refraction_index, heigth_substrate,
                        refraction_index_substrate, angle):
         """Insert a ronchi grating in background.
 
         Parameters:
+            r0 (float, float): (x0,z0) Location of the rectangle, for example (0 * um, 20 * um)
             period (float): period of the grating
             fill_factor (float): [0,1], fill factor of the grating
             length (float): length of the grating
             height (float): height of the grating
-            r0 (float, float): (x0,z0) Location of the rectangle, for example (0 * um, 20 * um)
             Dx (float): displacement of grating with respect x=0
             refraction_index (float, str): refraction index , for example: 1.5 + 1.0j
             heigth_substrate (float): height of the substrate
@@ -1241,7 +1264,7 @@ class Scalar_mask_XZ(Scalar_field_XZ):
         Xrot, Zrot = self.__rotate__(angle, r0)
 
         t0 = Scalar_mask_X(x=self.x, wavelength=self.wavelength)
-        t0.ronchi_grating(period=period, x0=Dx, fill_factor=fill_factor)
+        t0.ronchi_grating(x0=Dx, period=period, fill_factor=fill_factor)
 
         self.extrude_mask(
             t=t0,
@@ -1389,46 +1412,3 @@ class Scalar_mask_XZ(Scalar_field_XZ):
         self.rotate_field(
             angle, rotation_point, n_background=self.n_background)
         return ipasa
-
-    def wessenplatten(self, n_layers, sigma, correlation_length):
-        """Make a surface rough.
-
-            Parameters:
-            n_layers (int): number of layers
-            sigma (float): standard deviation in heights
-            correlation_length (float): correlation length
-        """
-        t1 = Scalar_mask_XZ(
-            x=self.x,
-            z=self.z,
-            wavelength=self.wavelength,
-            n_background=self.n_background,
-            info='')
-        for i, n_layer in enumerate(n_layers[:-1]):
-            indice_average = (n_layers[i] + n_layers[i + 1]) / 2
-
-            x_lens_l, h_lens_l, x_lens_r, h_lens_r = self.detect_index_variations(
-                n_edge=n_layers[i])
-
-            roughness_envelope_l = (
-                np.abs(x_lens_l) - x_lens_l.max()) / x_lens_l.max()
-            roughness_envelope_r = (
-                np.abs(x_lens_r) - x_lens_r.max()) / x_lens_r.max()
-
-            h_lens_l = h_lens_l + roughness_envelope_l * sigma * (
-                np.random.rand(len(x_lens_l)) - 0.5)
-            h_lens_r = h_lens_r + roughness_envelope_r * sigma * (
-                np.random.rand(len(x_lens_r)) - 0.5)
-
-            array1 = np.array([x_lens_l, h_lens_l]).transpose()
-            array2 = np.array([x_lens_r, h_lens_r]).transpose()
-            t1.mask_from_array(
-                r0=(0 * um, 0 * um),
-                refraction_index=indice_average,
-                array1=array1,
-                array2=array2,
-                x_sides=(-5 * mm, 5 * mm),
-                angle=0 * degrees,
-                v_globals={},
-                interp_kind='linear')
-        self.n = t1.n
