@@ -10,7 +10,7 @@ import scipy.ndimage as ndimage
 from numpy import angle, array, exp, linspace, ones_like, pi, zeros
 from scipy.signal import fftconvolve
 
-from diffractio import mm
+from . import mm
 
 
 def distance(x1, x2):
@@ -66,7 +66,7 @@ def nearest2(vector, numbers):
     return indexes, values, distances
 
 
-def find_extrema(array2D, x, y, kind='max', verbose=True):
+def find_extrema(array2D, x, y, kind='max', verbose=False):
     """In a 2D-array, formed by vectors x, and y, the maxima or minima are found
 
     Parameters:
@@ -75,6 +75,11 @@ def find_extrema(array2D, x, y, kind='max', verbose=True):
         y (np.array 1D): 1D array with y axis
         kind (str): 'min' or 'max': detects minima or maxima
         verbose (bool): If True prints data.
+
+    Returns:
+        indexes (int,int): indexes of the position
+        xy_ext (float, float): position of maximum
+        extrema (float): value of maximum
     """
 
     if kind == 'max':
@@ -86,7 +91,7 @@ def find_extrema(array2D, x, y, kind='max', verbose=True):
 
     num_extrema = len(listOfCordinates)
 
-    indexes = np.zeros((num_extrema, 2))
+    indexes = np.zeros((num_extrema, 2), dtype=np.integer)
     xy_ext = np.zeros((num_extrema, 2))
     extrema = np.zeros((num_extrema))
 
@@ -106,7 +111,7 @@ def find_extrema(array2D, x, y, kind='max', verbose=True):
 def ndgrid(*args, **kwargs):
     """n-dimensional gridding like Matlab's NDGRID
 
-    Arguments:
+    Parameters:
         The input *args are an arbitrary number of numerical sequences, e.g. lists, arrays, or tuples.
         The i-th dimension of the i-th output argument
         has copies of the i-th input argument.
@@ -359,8 +364,8 @@ def discretize(u,
         heights = np.linspace(0, 1, num_levels)
         posX = 256 / num_levels
 
-        amplitude = get_amplitude(matrix=True, new_field=False)
-        phase = get_phase(matrix=True, new_field=False)
+        amplitude = get_amplitude(u)
+        phase = get_phase(u)
         discretized_image = amplitude
 
         dist = factor * posX
@@ -375,9 +380,9 @@ def discretize(u,
         fieldDiscretizado = discretized_image * phase
 
     if kind == 'phase':
-        ang = angle(get_phase(matrix=True, new_field=False)) + phase0 + pi
+        ang = angle(get_phase(UnboundLocalError)) + phase0 + pi
         ang = ang % (2 * pi)
-        amplitude = get_amplitude(matrix=True, new_field=False)
+        amplitude = get_amplitude(u)
 
         heights = linspace(0, 2 * pi, num_levels + 1)
 
@@ -818,7 +823,7 @@ def laguerre_polynomial_nk(x, n=4, k=5):
 def get_k(x, flavour='-'):
     """provides k vector from x vector. Two flavours are provided (ordered + or disordered - )
 
-    Arguments:
+    Parameters:
         x (np.array): x array
         flavour (str): '+' or '-'
 
@@ -848,7 +853,7 @@ def get_k(x, flavour='-'):
 def filter_edge_1D(x, size=1.1, exponent=32):
     """function 1 at center and reduced at borders. For propagation algorithms
 
-    Arguments:
+    Parameters:
         x (np.array): position
         size (float): related to relative position of x
         exponent (integer): related to shape of edges
@@ -856,7 +861,33 @@ def filter_edge_1D(x, size=1.1, exponent=32):
         np.array: function for filtering
     """
 
-    num_x = len(x)
+    # num_x = len(x)
     x_center = (x[-1] + x[0]) / 2
     Dx = size * (x[-1] - x[0])
     return np.exp(-(2 * (x - x_center) / (Dx))**np.abs(exponent))
+
+
+def filter_edge_2D(x, y, size=1.1, exponent=32):
+    """function 1 at center and reduced at borders. For propagation algorithms
+
+    Parameters:
+        x (np.array): x position
+        y (np.array): y position
+        size (float): related to relative position of x and y
+        exponent (integer): related to shape of edges
+    Returns:
+        np.array: function for filtering
+    """
+
+    # num_x = len(x)
+    x_center = (x[-1] + x[0]) / 2
+    y_center = (y[-1] + y[0]) / 2
+    Dx = size * (x[-1] - x[0])
+    Dy = size * (y[-1] - y[0])
+
+    X, Y = np.meshgrid(x, y)
+
+    exp1 = np.exp(-(2 * (X - x_center) / (Dx))**np.abs(exponent))
+    exp2 = np.exp(-(2 * (Y - y_center) / (Dy))**np.abs(exponent))
+
+    return exp1 * exp2
