@@ -7,7 +7,8 @@ from numpy import (angle, arcsin, cos, exp, imag, meshgrid, pi, real, sign,
                    sin, sqrt, unwrap)
 
 from . import degrees, np, plt
-from .utils_math import fft_convolution1d, fft_convolution2d, nearest
+from .utils_math import (fft_convolution1d, fft_convolution2d, find_extrema,
+                         ndgrid, nearest)
 
 
 def roughness_1D(x, t, s, kind='normal'):
@@ -100,7 +101,7 @@ def roughness_2D(x, y, t, s):
     return h_corr
 
 
-def beam_width_1D(u, x):
+def beam_width_1D(u, x, remove_background=None):
     """One dimensional beam width, according to D4σ or second moment width.
 
     Parameters:
@@ -117,6 +118,9 @@ def beam_width_1D(u, x):
 
     intensity = np.abs(u)**4
 
+    if remove_background is True:
+        intensity = intensity - intensity - min()
+
     P = (intensity).sum()
     x_mean = (intensity * x).sum() / P
     x2_mean = (intensity * (x - x_mean)**2).sum() / P
@@ -172,7 +176,7 @@ def width_percentaje(x, y, percentaje=0.5, verbose=False):
     return width, x_list, i_list
 
 
-def beam_width_2D(x, y, intensity):
+def beam_width_2D(x, y, intensity, remove_background=False, has_draw=False):
     """2D beam width, ISO11146 width
 
 
@@ -195,8 +199,9 @@ def beam_width_2D(x, y, intensity):
 
 
     """
-    X, Y = np.meshgrid(x, y)
-    intensity = intensity - intensity.min()
+    X, Y = ndgrid(x, y)
+    if remove_background is True:
+        intensity = intensity - intensity - min()
 
     P = intensity.sum()
     x_mean = (intensity * X).sum() / P
@@ -204,12 +209,37 @@ def beam_width_2D(x, y, intensity):
     x2_mean = (intensity * (X - x_mean)**2).sum() / P
     y2_mean = (intensity * (Y - y_mean)**2).sum() / P
     xy_mean = (intensity * (X - x_mean) * (Y - y_mean)).sum() / P
-    gamma = (x2_mean - y2_mean) / np.abs(x2_mean - y2_mean + 1e-16)
+    # gamma = (x2_mean - y2_mean) / np.abs(x2_mean - y2_mean + 1e-16)
+    gamma = np.sign(x2_mean - y2_mean + 0.0000000001)
+    rt = sqrt(
+        (x2_mean - y2_mean)**2 + 4 * xy_mean**2)
+    dx = 2 * sqrt(2) * sqrt(x2_mean + y2_mean + gamma * rt)
+    dy = 2 * sqrt(2) * sqrt(x2_mean + y2_mean - gamma * rt)
+
+    # print(gamma)
+    # print(rt)
+    # print(x2_mean, y2_mean, rt, dx, dy)
+
     principal_axis = 0.5 * np.arctan2(2 * xy_mean, x2_mean - y2_mean)
-    dx = 2 * sqrt(2) * sqrt(x2_mean + y2_mean + gamma * sqrt(
-        (x2_mean - y2_mean)**2 + 4 * xy_mean**2))
-    dy = 2 * sqrt(2) * sqrt(x2_mean + y2_mean - gamma * sqrt(
-        (x2_mean - y2_mean)**2 + 4 * xy_mean**2))
+
+    if has_draw is True:
+        from matplotlib.patches import Ellipse
+
+        from .scalar_fields_XY import Scalar_field_XY
+
+        u0 = Scalar_field_XY(x, y, 1)
+        u0.u = np.sqrt(intensity)
+        u0.draw()
+        ellipse = Ellipse(xy=(x_mean, y_mean), width=dy,
+                          height=dx, angle=-principal_axis / degrees)
+
+        ax = plt.gca()
+        ax.add_artist(ellipse)
+        ellipse.set_clip_box(ax.bbox)
+        ellipse.set_alpha(0.75)
+        ellipse.set_facecolor('none')
+        ellipse.set_edgecolor([1, 1, 1])
+        ellipse.set_linewidth(3)
 
     return dx, dy, principal_axis, (x_mean, y_mean, x2_mean, y2_mean, xy_mean)
 
@@ -267,11 +297,11 @@ def refraction_index(filename, wavelength, raw=False, has_draw=True):
 def FWHM1D(x,
            intensity,
            percentaje=0.5,
-           remove_background='mean',
-           has_drawing=False):
-    """FWHM
+           remove_background=None,
+           has_draw=False):
+    """FWHM1D
 
-    remove_background = 'min', 'mean', 'None'"""
+    remove_background = 'min', 'mean', None"""
 
     if remove_background == 'mean':
         I_background = intensity.mean()
@@ -309,7 +339,7 @@ def FWHM1D(x,
 
     intensity = intensity + I_background
 
-    if has_drawing is True:
+    if has_draw is True:
         if remove_background is True:
             intensity = intensity + intensity.min()
         plt.figure()
@@ -320,12 +350,10 @@ def FWHM1D(x,
 
         plt.plot(x[i_max], intensity[i_max], 'ro', ms=8)
         plt.plot(
-            x[int(i_left)] + distance_left, intensity[int(i_left)], 'ro', ms=8)
-        plt.plot(
-            x[int(i_right)] + distance_right,
-            intensity[int(i_right)],
-            'ro',
-            ms=8)
+            x[int(i_right)], intensity[int(i_left)], 'ro', ms=8)
+        plt.plot(x[int(i_left)], intensity[int(i_right)], 'ro', ms=8)
+        plt.ylim(ymin=0)
+        plt.xlim(x[0], x[-1])
 
     return FWHM_x
 
@@ -335,15 +363,29 @@ def FWHM2D(x,
            intensity,
            percentaje=0.5,
            remove_background='None',
-           has_drawing=False):
+           has_draw=False,
+           xlim=None):
+    """TODO: perform profiles at several angles and fit to a ellipse.
+        Get dx, dy, angle, x_center, y_center"""
+    # Ix = intensity.mean(axis=0)
+    # Iy = intensity.mean(axis=1)
 
-    Ix = intensity.mean(axis=0)
-    Iy = intensity.mean(axis=1)
+    i_pos, _, I_max = find_extrema(intensity.transpose(), x, y, kind='max')
 
-    FWHM_x = FWHM1D(
-        x, Ix, percentaje, remove_background, has_drawing=has_drawing)
-    FWHM_y = FWHM1D(
-        y, Iy, percentaje, remove_background, has_drawing=has_drawing)
+    Ix = intensity[:, i_pos[0, 1]]
+    Iy = intensity[i_pos[0, 0], :]
+
+    # print(x.shape, Iy.shape)
+    FWHM_x = FWHM1D(x, Ix, percentaje, remove_background, has_draw=has_draw)
+    if has_draw is True:
+        if xlim is not None:
+            plt.xlim(xlim)
+
+    # print(y.shape, Iy.shape)
+    FWHM_y = FWHM1D(y, Iy, percentaje, remove_background, has_draw=has_draw)
+    if has_draw is True:
+        if xlim is not None:
+            plt.xlim(xlim)
 
     return FWHM_x, FWHM_y
 
@@ -413,7 +455,7 @@ Returns:
         plt.plot([z[i_right + i_w0], z[i_right + i_w0]],
                  [-widths[i_right + i_w0], widths[i_right + i_w0]], 'r--')
         plt.annotate(
-            s='',
+            text='',
             xy=(z[i_left], -widths[i_right + i_w0]),
             xytext=(z[i_right + i_w0], -widths[i_right + i_w0]),
             arrowprops=dict(arrowstyle='<->'))
@@ -460,7 +502,7 @@ def detect_intensity_range(x,
     x_max = x[i_max]
 
     if has_draw is True:
-        fig, ax = plt.subplots()
+        _, ax = plt.subplots()
 
         if logarithm is True:
             I2 = np.log(intensity + 1)
@@ -710,6 +752,7 @@ def field_parameters(u, has_amplitude_sign=False):
 
     intensity = np.abs(u)**2
     phase = np.angle(u)
+
     if has_amplitude_sign is True:
         amplitude = np.sign(u) * np.abs(u)
     else:
@@ -759,8 +802,6 @@ def convert_amplitude2heigths(amplitude, wavelength, kappa, n_background):
 
     amplitude[amplitude < eps_depth] = eps_depth
 
-    k = 2 * np.pi / wavelength
-
     depth = np.log(amplitude) * wavelength / (-2 * np.pi * kappa)
 
     return depth
