@@ -6,7 +6,7 @@ import datetime
 import os
 import sys
 
-from diffractio import degrees, mm, no_date, np, plt, sp, um
+from diffractio import degrees, mm, no_date, np, plt, um
 from diffractio.scalar_masks_XY import Scalar_mask_XY
 from diffractio.utils_tests import comparison, save_figure_test
 
@@ -50,7 +50,7 @@ class Test_Scalar_masks_XY(object):
         t3.draw(title='suma')
 
         t1.save_data(
-            filename=filename, method='savez_compressed', add_name='_1')
+            filename=filename + '.npz', add_name='_1')
         save_figure_test(newpath, func_name, add_name='_1')
 
         func_name = sys._getframe().f_code.co_name
@@ -80,7 +80,7 @@ class Test_Scalar_masks_XY(object):
         t3.draw(title='add')
 
         t3.save_data(
-            filename=filename, method='savez_compressed', add_name='_2')
+            filename=filename + '.npz', add_name='_2')
         save_figure_test(newpath, func_name, add_name='_2')
         assert True
 
@@ -107,7 +107,7 @@ class Test_Scalar_masks_XY(object):
         t3 = t2 - t1
         t3.draw(title='resta')
 
-        t3.save_data(filename=filename, method='savez_compressed')
+        t3.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -130,7 +130,7 @@ class Test_Scalar_masks_XY(object):
         t1.draw(kind='field')
         plt.title('(0,1)-sin binarizar')
         t1.save_data(
-            filename=filename, method='savez_compressed', add_name='_wo_bin')
+            filename=filename + '.npz', add_name='_wo_bin')
         save_figure_test(newpath, func_name, '_wo_bin')
         t1.binarize(
             kind='amplitude',
@@ -143,7 +143,7 @@ class Test_Scalar_masks_XY(object):
         plt.suptitle('binarizada')
 
         t1.save_data(
-            filename=filename, method='savez_compressed', add_name='_wi_bin')
+            filename=filename + '.npz', add_name='_wi_bin')
         save_figure_test(newpath, func_name, add_name='_wi_bin')
         assert True
 
@@ -161,7 +161,7 @@ class Test_Scalar_masks_XY(object):
         t1.slit(x0=0, size=100 * um, angle=0 * degrees)
         t1.draw(kind='intensity')
 
-        t1.save_data(filename=filename, method='savez_compressed')
+        t1.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -183,7 +183,29 @@ class Test_Scalar_masks_XY(object):
             period=100 * um)
         t1.draw(kind='intensity')
 
-        t1.save_data(filename=filename, method='savez_compressed')
+        t1.save_data(filename=filename + '.npz')
+        save_figure_test(newpath, func_name)
+        assert True
+
+    def test_slit_series(self):
+        func_name = sys._getframe().f_code.co_name
+        filename = '{}{}'.format(newpath, func_name)
+
+        num_data = 256
+        length = 1000 * um
+        x0 = np.linspace(-length / 2, length / 2, num_data)
+        y0 = np.linspace(-length / 2, length / 2, num_data)
+        wavelength = 0.6328 * um
+
+        a_coef1 = np.array([[0, 1, 2], [0, 25, 25]])
+        a_coef2 = np.array([[0, 1, 2], [0, 25, 25]])
+
+        t1 = Scalar_mask_XY(x=x0, y=y0, wavelength=wavelength)
+        t1.slit_series(x0=0, width=200, period1=100, period2=100, Dy=(0, 0),
+                       a_coef1=a_coef1, a_coef2=a_coef2, angle=0 * degrees)
+        t1.draw()
+
+        t1.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -204,7 +226,7 @@ class Test_Scalar_masks_XY(object):
             n=[0.5, 4])
         t1.draw(kind='intensity')
 
-        t1.save_data(filename=filename, method='savez_compressed')
+        t1.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -225,7 +247,7 @@ class Test_Scalar_masks_XY(object):
             n=[0.5, 4])
         t1.draw(kind='intensity')
 
-        t1.save_data(filename=filename, method='savez_compressed')
+        t1.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -244,7 +266,7 @@ class Test_Scalar_masks_XY(object):
             x0=0, size=5 * um, separation=15 * um, angle=0 * degrees)
         t1.draw(kind='intensity')
 
-        t1.save_data(filename=filename, method='savez_compressed')
+        t1.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -260,7 +282,7 @@ class Test_Scalar_masks_XY(object):
         t1.triangle(r0=(0, 0), slope=1, height=50 * um, angle=0 * degrees)
         t1.draw(kind='intensity')
 
-        t1.save_data(filename=filename, method='savez_compressed')
+        t1.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -277,14 +299,14 @@ class Test_Scalar_masks_XY(object):
             r0=(0 * um, 0 * um), size=(90 * um, 25 * um), angle=0 * degrees)
 
         t1 = Scalar_mask_XY(x, y, wavelength)
-        num_points = t1.insert_array_masks(
+        t1.insert_array_masks(
             t1=s,
             space=[100 * um, 100 * um],
             margin=50 * um,
             angle=90 * degrees)
         t1.draw(kind='intensity')
 
-        t1.save_data(filename=filename, method='savez_compressed')
+        t1.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -303,7 +325,7 @@ class Test_Scalar_masks_XY(object):
             r0=(0 * um, 0 * um), size=(100 * um, 50 * um), angle=45 * degrees)
         t1.draw(kind='intensity')
 
-        t1.save_data(filename=filename, method='savez_compressed')
+        t1.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -321,7 +343,7 @@ class Test_Scalar_masks_XY(object):
         t1.circle(r0=(0 * um, 0 * um), radius=(100 * um, 100 * um))
         t1.draw(kind='intensity')
 
-        t1.save_data(filename=filename, method='savez_compressed')
+        t1.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -343,7 +365,7 @@ class Test_Scalar_masks_XY(object):
             potencia=22)
         t1.draw(kind='intensity')
 
-        t1.save_data(filename=filename, method='savez_compressed')
+        t1.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -368,7 +390,26 @@ class Test_Scalar_masks_XY(object):
         # t2 = t1.fft(remove0=False)
         # t2.draw(logarithm=True)
 
-        t1.save_data(filename=filename, method='savez_compressed')
+        t1.save_data(filename=filename + '.npz')
+        save_figure_test(newpath, func_name)
+        assert True
+
+    def test_angular_aperture(self):
+        func_name = sys._getframe().f_code.co_name
+        filename = '{}{}'.format(newpath, func_name)
+
+        num_pixels = 512
+        length = 200 * um
+        x0 = np.linspace(-length / 2, length / 2, num_pixels)
+        y0 = np.linspace(-length / 2, length / 2, num_pixels)
+        wavelength = 0.6238 * um
+
+        t1 = Scalar_mask_XY(x=x0, y=y0, wavelength=wavelength)
+        a_coef = np.array([[0, 4, 8], [50, 25, 25]])
+        t1.angular_aperture(a_coef=a_coef, angle=0 * degrees)
+        t1.draw()
+
+        t1.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -387,7 +428,7 @@ class Test_Scalar_masks_XY(object):
             r0=(0 * um, 0 * um), radius=(50 * um, 25 * um), angle=45 * degrees)
         t1.draw(kind='intensity')
 
-        t1.save_data(filename=filename, method='savez_compressed')
+        t1.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -409,10 +450,34 @@ class Test_Scalar_masks_XY(object):
             angle=45 * degrees)
         t1.draw(kind='intensity')
 
-        t1.save_data(filename=filename, method='savez_compressed')
+        t1.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
+    def test_rings(self):
+        func_name = sys._getframe().f_code.co_name
+        filename = '{}{}'.format(newpath, func_name)
+
+        length = 60 * um
+        num_data = 512
+        x = np.linspace(-length / 2, length / 2, num_data)
+        y = np.linspace(-length / 2, length / 2, num_data)
+        wavelength = 0.6328 * um
+
+        inner_radius = np.array([5., 10, 15, 20, 25])
+
+        outer_radius = np.array([6., 12, 17, 23, 29])
+
+        t1 = Scalar_mask_XY(x, y, wavelength)
+        t1.rings(r0=(0, 0), inner_radius=inner_radius,
+                 outer_radius=outer_radius, mask=True)
+        t1.draw(kind='intensity')
+
+        t1.save_data(filename=filename + '.npz')
+        save_figure_test(newpath, func_name)
+        assert True
+        num_data = 512
+
     def test_cross(self):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
@@ -428,7 +493,7 @@ class Test_Scalar_masks_XY(object):
             r0=(0 * um, 0 * um), size=(200 * um, 75 * um), angle=0 * degrees)
         t1.draw(kind='intensity')
 
-        t1.save_data(filename=filename, method='savez_compressed')
+        t1.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -443,32 +508,34 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6328 * um
 
         t1 = Scalar_mask_XY(x, y, wavelength)
-        t1.two_levels(level1=0, level2=.5, xcorte=0)
+        t1.two_levels(level1=0, level2=.5, x_edge=0)
         t1.draw(kind='intensity')
 
-        t1.save_data(filename=filename, method='savez_compressed')
+        t1.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
-    # def test_image(self):
-    #     func_name = sys._getframe().f_code.co_name
-    #     filename = '{}{}'.format(newpath, func_name)
-    #
-    #     num_data = 1204
-    #     length = 250 * um
-    #     x = np.linspace(-length / 2, length / 2, num_data)
-    #     y = np.linspace(-length / 2, length / 2, num_data)
-    #     wavelength = 0.6328 * um
-    #
-    #     t1 = Scalar_mask_XY(x, y, wavelength)
-    #     # t1.image(nombre=*, normalize=True, canal=0, lengthImage=True, angle=45)
-    #     t1.image(filename="./images/spain.png")
-    #
-    #     t1.draw(kind='intensity')
-    #
-    #     t1.save_data(filename=filename, method='savez_compressed')
-    #     save_figure_test(newpath, func_name)
-    #     assert True
+    def test_edge_series(self):
+        func_name = sys._getframe().f_code.co_name
+        filename = '{}{}'.format(newpath, func_name)
+
+        num_pixels = 512
+        length = 1000 * um
+        x0 = np.linspace(-length / 2, length / 2, num_pixels)
+        y0 = np.linspace(-length / 2, length / 2, num_pixels)
+        wavelength = 0.06238 * um
+
+        a_coef = np.array([[0, 1, 2], [0, 100, 25]])
+        b_coef = np.array([[0, 3], [0, 25]])
+
+        t1 = Scalar_mask_XY(x=x0, y=y0, wavelength=wavelength)
+        t1.edge_series(r0=(0, 0), period=100, a_coef=a_coef, b_coef=b_coef,
+                       angle=0 * degrees, invert=False)
+        t1.draw()
+
+        t1.save_data(filename=filename + '.npz')
+        save_figure_test(newpath, func_name)
+        assert True
 
     def test_gray_scale(self):
         func_name = sys._getframe().f_code.co_name
@@ -484,7 +551,7 @@ class Test_Scalar_masks_XY(object):
         t1.gray_scale(num_levels=128, levelMin=0, levelMax=1)
         t1.draw(kind='intensity')
 
-        t1.save_data(filename=filename, method='savez_compressed')
+        t1.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -509,7 +576,7 @@ class Test_Scalar_masks_XY(object):
             mask=True)
         t1.draw(kind='field')
 
-        t1.save_data(filename=filename, method='savez_compressed')
+        t1.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -556,7 +623,7 @@ class Test_Scalar_masks_XY(object):
         t2 = t1.RS(z=focal)
         t2.draw(kind='field', logarithm=True)
 
-        t1.save_data(filename=filename, method='savez_compressed')
+        t1.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -578,7 +645,7 @@ class Test_Scalar_masks_XY(object):
             angle=0 * degrees)
         t0.draw(kind='phase')
 
-        t0.save_data(filename=filename, method='savez_compressed')
+        t0.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
 
         t1 = Scalar_mask_XY(x, y, wavelength)
@@ -589,10 +656,7 @@ class Test_Scalar_masks_XY(object):
             angle=45 * degrees)
         t1.draw(kind='phase')
 
-        t1.save_data(
-            filename=filename,
-            method='savez_compressed',
-            add_name='_elliptical')
+        t1.save_data(filename=filename + '.npz', add_name='_elliptical')
         save_figure_test(newpath, func_name, add_name='_elliptical')
         assert True
 
@@ -616,7 +680,7 @@ class Test_Scalar_masks_XY(object):
             phase=np.pi)
         t1.draw(kind='intensity')
         t1.save_data(
-            filename=filename, method='savez_compressed', add_name='_int')
+            filename=filename + '.npz', add_name='_int')
         save_figure_test(newpath, func_name, add_name='_int')
 
         t1.fresnel_lens(
@@ -629,33 +693,10 @@ class Test_Scalar_masks_XY(object):
         t1.draw(kind='phase')
 
         t1.save_data(
-            filename=filename, method='savez_compressed', add_name='_phase')
+            filename=filename + '.npz', add_name='_phase')
         save_figure_test(newpath, func_name, add_name='_phase')
         assert True
 
-    def test_lens_billet(self):
-        func_name = sys._getframe().f_code.co_name
-        filename = '{}{}'.format(newpath, func_name)
-
-        num_data = 512
-        length = 250 * um
-        x = np.linspace(-length / 2, length / 2, num_data)
-        y = np.linspace(-length / 2, length / 2, num_data)
-        wavelength = 0.6328 * um
-
-        t1 = Scalar_mask_XY(x, y, wavelength)
-        t1.lens_billet(
-            r0=(0 * um, 0 * um),
-            radius=(200 * um, 200 * um),
-            focal=(5 * mm, 5 * mm),
-            angle=0 * degrees,
-            radius_agujero=50 * um)
-        t1.draw(kind='phase')
-
-        t1.save_data(filename=filename, method='savez_compressed')
-        save_figure_test(newpath, func_name)
-        assert True
-
     def test_biprism_fresnel(self):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
@@ -671,7 +712,7 @@ class Test_Scalar_masks_XY(object):
             r0=(0 * um, 0 * um), width=100 * um, height=5 * um, n=1.5)
         t1.draw(kind='field')
         save_figure_test(newpath, func_name)
-        t1.save_data(filename=filename, method='savez_compressed')
+        t1.save_data(filename=filename + '.npz')
         assert True
 
     def test_axicon(self):
@@ -685,11 +726,12 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6328 * um
 
         t1 = Scalar_mask_XY(x, y, wavelength)
-        t1.axicon(r0=(0 * um, 0 * um), radius=100 * um, height=2 * um, n=1.5)
+        t1.axicon(r0=(0 * um, 0 * um), radius=100 * um,
+                  angle=2 * degrees, refraction_index=1.5)
         t1.draw(kind='phase')
 
         save_figure_test(newpath, func_name)
-        t1.save_data(filename=filename, method='savez_compressed')
+        t1.save_data(filename=filename + '.npz')
         assert True
 
     def test_laguerre_gauss_spiral(self):
@@ -705,24 +747,24 @@ class Test_Scalar_masks_XY(object):
         t = Scalar_mask_XY(x, y, wavelength)
         t.laguerre_gauss_spiral(
             kind='intensity',
+            n=2,
             l=4,
             r0=(0 * um, 0 * um),
             w0=20 * um,
             z=0.01 * um)
         t.draw(kind='intensity')
         t.save_data(
-            filename=filename,
-            method='savez_compressed',
+            filename=filename + '.npz',
             add_name='_intensity')
         save_figure_test(newpath, func_name, add_name='_intensity')
 
         t2 = Scalar_mask_XY(x, y, wavelength)
         t2.laguerre_gauss_spiral(
-            kind='phase', l=4, r0=(0 * um, 0 * um), w0=20 * um, z=0.01 * um)
+            kind='phase', n=2, l=4, r0=(0 * um, 0 * um), w0=20 * um, z=0.01 * um)
         t2.draw(kind='phase')
 
         t2.save_data(
-            filename=filename, method='savez_compressed', add_name='_phase')
+            filename=filename + '.npz', add_name='_phase')
         save_figure_test(newpath, func_name, add_name='_phase')
         assert True
 
@@ -746,7 +788,7 @@ class Test_Scalar_masks_XY(object):
             angle=0 * degrees)
         t.draw(kind='intensity')
 
-        t.save_data(filename=filename, method='savez_compressed')
+        t.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -764,7 +806,7 @@ class Test_Scalar_masks_XY(object):
         t1.roughness(t=(25 * um, 25 * um), s=1 * um)
         t1.draw(kind='phase')
 
-        t1.save_data(filename=filename, method='savez_compressed')
+        t1.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -781,7 +823,7 @@ class Test_Scalar_masks_XY(object):
             period=period, amp_min=0, amp_max=1, x0=0 * um, angle=0 * degrees)
         red.draw(kind='intensity')
 
-        red.save_data(filename=filename, method='savez_compressed')
+        red.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -797,7 +839,7 @@ class Test_Scalar_masks_XY(object):
             period=100 * um, x0=0 * um, angle=0 * degrees, fill_factor=0.333)
         red.draw(kind='intensity')
 
-        red.save_data(filename=filename, method='savez_compressed')
+        red.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -819,7 +861,7 @@ class Test_Scalar_masks_XY(object):
             angle=0 * degrees)
         red.draw(kind='field')
 
-        red.save_data(filename=filename, method='savez_compressed')
+        red.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -841,7 +883,7 @@ class Test_Scalar_masks_XY(object):
             angle=0 * degrees)
         red.draw(kind='phase')
 
-        red.save_data(filename=filename, method='savez_compressed')
+        red.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -858,7 +900,7 @@ class Test_Scalar_masks_XY(object):
             period=period, height=2 * um, index=1.5, x0=0, angle=0 * degrees)
         red.draw(kind='phase')
 
-        red.save_data(filename=filename, method='savez_compressed')
+        red.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -871,17 +913,16 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6238 * um
         period = 62.5 * um
         red = Scalar_mask_XY(x, y, wavelength)
-        red.grating_2D(
-            period=period,
-            amin=0,
-            amax=1.,
-            phase=0 * np.pi / 2,
-            x0=0,
-            fill_factor=0.5,
-            angle=0 * degrees)
+        red.grating_2D(r0=(0., 0.),
+                       period=period,
+                       amin=0,
+                       amax=1.,
+                       phase=0 * np.pi / 2,
+                       fill_factor=0.5,
+                       angle=0 * degrees)
         red.draw(kind='intensity')
 
-        red.save_data(filename=filename, method='savez_compressed')
+        red.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -894,17 +935,16 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6238 * um
         period = 125 * um
         red = Scalar_mask_XY(x, y, wavelength)
-        red.grating_2D_chess(
-            period=period,
-            amin=0,
-            amax=1.,
-            phase=0 * np.pi / 2,
-            x0=0,
-            fill_factor=0.75,
-            angle=0 * degrees)
+        red.grating_2D_chess(r0=(0., 0.),
+                             period=period,
+                             amin=0,
+                             amax=1.,
+                             phase=0 * np.pi / 2,
+                             fill_factor=0.75,
+                             angle=0 * degrees)
         red.draw(kind='intensity')
 
-        red.save_data(filename=filename, method='savez_compressed')
+        red.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -926,7 +966,7 @@ class Test_Scalar_masks_XY(object):
             sigma=4 * um,
             correlation_length=.1 * um)
         t.draw(kind='intensity')
-        t.save_data(filename=filename, method='savez_compressed')
+        t.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -948,7 +988,7 @@ class Test_Scalar_masks_XY(object):
             correlation_length=.1 * um)
         t.draw(kind='intensity')
 
-        t.save_data(filename=filename, method='savez_compressed')
+        t.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -970,8 +1010,7 @@ class Test_Scalar_masks_XY(object):
             angle=45 * degrees)
         t1.draw()
         t1.save_data(
-            filename=filename,
-            method='savez_compressed',
+            filename=filename + '.npz',
             add_name='_no_widened')
         save_figure_test(newpath, func_name, add_name='_no_widened')
 
@@ -982,7 +1021,7 @@ class Test_Scalar_masks_XY(object):
         t1.draw()
 
         t1.save_data(
-            filename=filename, method='savez_compressed', add_name='_widened')
+            filename=filename + '.npz', add_name='_widened')
         save_figure_test(newpath, func_name, add_name='_widened')
         assert True
 
@@ -1008,6 +1047,6 @@ class Test_Scalar_masks_XY(object):
         text1 = "The area is: {:2.4f} %".format(area * 100)
         plt.title(text1)
 
-        t1.save_data(filename=filename, method='savez_compressed')
+        t1.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
