@@ -5,13 +5,11 @@ import datetime
 import os
 import sys
 
-from numpy import loadtxt
-
-from diffractio import degrees, mm, no_date, np, plt, sp, um
+from diffractio import degrees, mm, no_date, np, um
 from diffractio.scalar_masks_X import Scalar_mask_X
 from diffractio.scalar_masks_XZ import Scalar_mask_XZ
-from diffractio.scalar_sources_X import Scalar_source_X
 from diffractio.utils_tests import comparison, save_figure_test
+from numpy import loadtxt
 
 if no_date is True:
     date = '0'
@@ -36,8 +34,8 @@ class Test_Scalar_masks_XZ(object):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
 
-        x0 = np.linspace(-100 * um, 100 * um, 512)
-        z0 = np.linspace(0 * um, 400 * um, 512)
+        x0 = np.linspace(-100 * um, 100 * um, 256)
+        z0 = np.linspace(0 * um, 400 * um, 256)
         wavelength = .55 * um
 
         t0 = Scalar_mask_X(x=x0, wavelength=wavelength)
@@ -56,7 +54,7 @@ class Test_Scalar_masks_XZ(object):
             v_globals=v_globals)
         t1.draw_refraction_index(draw_borders=False, )
 
-        t1.save_data(filename=filename, method='savez_compressed', add_name='')
+        t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
@@ -64,8 +62,8 @@ class Test_Scalar_masks_XZ(object):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
 
-        x0 = np.linspace(-100 * um, 100 * um, 512)
-        z0 = np.linspace(0 * um, 400 * um, 512)
+        x0 = np.linspace(-100 * um, 100 * um, 256)
+        z0 = np.linspace(0 * um, 400 * um, 256)
         wavelength = .55 * um
 
         t0 = Scalar_mask_X(x=x0, wavelength=wavelength)
@@ -80,7 +78,7 @@ class Test_Scalar_masks_XZ(object):
             t=t0, z0=z0, z1=z1, refraction_index=1.5, v_globals=v_globals)
         t1.draw_refraction_index(draw_borders=False, )
 
-        t1.save_data(filename=filename, method='savez_compressed', add_name='')
+        t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
@@ -88,8 +86,8 @@ class Test_Scalar_masks_XZ(object):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
 
-        x0 = np.linspace(-100 * um, 100 * um, 512)
-        z0 = np.linspace(0 * um, 500 * um, 512)
+        x0 = np.linspace(-100 * um, 100 * um, 256)
+        z0 = np.linspace(0 * um, 500 * um, 256)
         wavelength = 0.6238 * um
 
         f1 = '50 * um'
@@ -109,7 +107,7 @@ class Test_Scalar_masks_XZ(object):
 
         t1.draw_refraction_index()
 
-        t1.save_data(filename=filename, method='savez_compressed', add_name='')
+        t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
@@ -117,8 +115,8 @@ class Test_Scalar_masks_XZ(object):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
 
-        x = np.linspace(-15 * mm, 15 * mm, 512)
-        z = np.linspace(0 * mm, 15 * mm, 512)
+        x = np.linspace(-15 * mm, 15 * mm, 256)
+        z = np.linspace(0 * mm, 15 * mm, 256)
         wavelength = 0.6328 * um
 
         t1 = Scalar_mask_XZ(x, z, wavelength)
@@ -146,7 +144,7 @@ class Test_Scalar_masks_XZ(object):
 
         t1.draw_refraction_index(draw_borders=False)
 
-        t1.save_data(filename=filename, method='savez_compressed', add_name='')
+        t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
@@ -154,8 +152,8 @@ class Test_Scalar_masks_XZ(object):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
 
-        x0 = np.linspace(-20 * um, 20 * um, 512)
-        z0 = np.linspace(0 * um, 2000 * um, 512)
+        x0 = np.linspace(-20 * um, 20 * um, 256)
+        z0 = np.linspace(0 * um, 2000 * um, 256)
         wavelength = 2 * um
 
         r0 = (0, 0)
@@ -168,7 +166,7 @@ class Test_Scalar_masks_XZ(object):
 
         t1.draw_refraction_index(draw_borders=True)
 
-        t1.save_data(filename=filename, method='savez_compressed', add_name='')
+        t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
@@ -182,9 +180,9 @@ class Test_Scalar_masks_XZ(object):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
 
-        x0 = np.linspace(-100 * um, 100 * um, 512)
+        x0 = np.linspace(-100 * um, 100 * um, 256)
         print("Dx={}".format(x0[1] - x0[0]))
-        z0 = np.linspace(0 * um, 400 * um, 512)
+        z0 = np.linspace(0 * um, 400 * um, 256)
         wavelength = 50 * um
 
         t0 = Scalar_mask_XZ(
@@ -207,7 +205,7 @@ class Test_Scalar_masks_XZ(object):
 
         t0.draw_refraction_index(draw_borders=False, scale='equal')
 
-        t0.save_data(filename=filename, method='savez_compressed', add_name='')
+        t0.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
@@ -216,8 +214,8 @@ class Test_Scalar_masks_XZ(object):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
 
-        x0 = np.linspace(-100 * um, 100 * um, 512)
-        z0 = np.linspace(0 * um, 400 * um, 512)
+        x0 = np.linspace(-100 * um, 100 * um, 256)
+        z0 = np.linspace(0 * um, 400 * um, 256)
         wavelength = .55 * um
 
         t0 = Scalar_mask_X(x=x0, wavelength=wavelength)
@@ -236,7 +234,7 @@ class Test_Scalar_masks_XZ(object):
             v_globals=v_globals)
         t1.draw_refraction_index(draw_borders=False)
 
-        t1.save_data(filename=filename, method='savez_compressed', add_name='')
+        t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
@@ -245,9 +243,9 @@ class Test_Scalar_masks_XZ(object):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
 
-        x0 = np.linspace(-100 * um, 100 * um, 512)
+        x0 = np.linspace(-100 * um, 100 * um, 256)
         print("Dx={}".format(x0[1] - x0[0]))
-        z0 = np.linspace(0 * um, 400 * um, 512)
+        z0 = np.linspace(0 * um, 400 * um, 256)
         wavelength = 50 * um
 
         t0 = Scalar_mask_XZ(
@@ -272,47 +270,7 @@ class Test_Scalar_masks_XZ(object):
 
         t0.draw_refraction_index(draw_borders=False, scale='equal')
 
-        t0.save_data(filename=filename, method='savez_compressed', add_name='')
-        save_figure_test(newpath, func_name, add_name='')
-        assert True
-
-    def test_wessenplatten(self):
-
-        func_name = sys._getframe().f_code.co_name
-        filename = '{}{}'.format(newpath, func_name)
-
-        x0 = np.linspace(-100 * um, 100 * um, 512)
-        print("Dx={}".format(x0[1] - x0[0]))
-        z0 = np.linspace(0 * um, 400 * um, 512)
-        wavelength = 50 * um
-
-        t0 = Scalar_mask_XZ(
-            x=x0, z=z0, wavelength=wavelength, n_background=1.0)
-
-        pn = dict(
-            n_out=1.5, n_center=4, cx=0 * um, cz=100 * um, radius=75 * um)
-
-        center = (pn['cx'], pn['cz'])
-        radius = pn['radius']
-        # ref_index = '2*(((X-0)**2+(Z-300)**2)/75**2-0)'
-        ref_index = "{p[n_out]}+({p[n_center]}-{p[n_out]})*(1-((X-{p[cx]})**2+(Z-{p[cz]})**2)/{p[radius]}**2)".format(
-            p=pn)
-
-        t0.sphere(
-            r0=center,
-            radius=(radius, radius),
-            refraction_index=ref_index,
-            angle=0)
-
-        t0.wessenplatten(
-            n_layers=np.linspace(1.5, 4, 5),
-            sigma=10 * um,
-            correlation_length=25 * um,
-        )
-
-        t0.draw_refraction_index(draw_borders=False, scale='equal')
-
-        t0.save_data(filename=filename, method='savez_compressed', add_name='')
+        t0.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
@@ -324,8 +282,8 @@ class Test_Scalar_masks_XZ(object):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
 
-        x0 = np.linspace(-100 * um, 100 * um, 512)
-        z0 = np.linspace(0 * um, 400 * um, 512)
+        x0 = np.linspace(-100 * um, 100 * um, 256)
+        z0 = np.linspace(0 * um, 400 * um, 256)
         wavelength = 2 * um
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength, n_background=1)
@@ -353,7 +311,7 @@ class Test_Scalar_masks_XZ(object):
 
         t1.draw_refraction_index(draw_borders=False, scale='equal')
 
-        t1.save_data(filename=filename, method='savez_compressed', add_name='')
+        t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
@@ -365,8 +323,8 @@ class Test_Scalar_masks_XZ(object):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
 
-        x0 = np.linspace(-100 * um, 100 * um, 512)
-        z0 = np.linspace(0 * um, 400 * um, 512)
+        x0 = np.linspace(-100 * um, 100 * um, 256)
+        z0 = np.linspace(0 * um, 400 * um, 256)
         wavelength = .55 * um
 
         t0 = Scalar_mask_X(x=x0, wavelength=wavelength)
@@ -377,7 +335,7 @@ class Test_Scalar_masks_XZ(object):
             t=t0, z0=10 * um, z1=50 * um, refraction_index=1.5 - 1.5j)
         t1.draw_refraction_index(draw_borders=True)
 
-        t1.save_data(filename=filename, method='savez_compressed', add_name='')
+        t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
@@ -401,15 +359,15 @@ class Test_Scalar_masks_XZ(object):
             invert=False)
         t1.draw_refraction_index()
 
-        t1.save_data(filename=filename, method='savez_compressed', add_name='')
+        t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
     def test_semi_plane(self):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
-        x0 = np.linspace(-400 * um, 400 * um, 512)
-        z0 = np.linspace(-100 * um, 100 * um, 512)
+        x0 = np.linspace(-400 * um, 400 * um, 256)
+        z0 = np.linspace(-100 * um, 100 * um, 256)
         wavelength = .5 * um
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
@@ -420,15 +378,15 @@ class Test_Scalar_masks_XZ(object):
             rotation_point=None)
         t1.draw_refraction_index()
 
-        t1.save_data(filename=filename, method='savez_compressed', add_name='')
+        t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
     def test_layer(self):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
-        x0 = np.linspace(-200 * um, 200 * um, 512)
-        z0 = np.linspace(-100 * um, 100 * um, 512)
+        x0 = np.linspace(-200 * um, 200 * um, 256)
+        z0 = np.linspace(-100 * um, 100 * um, 256)
         wavelength = .5 * um
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
@@ -440,15 +398,15 @@ class Test_Scalar_masks_XZ(object):
             rotation_point=None)
         t1.draw_refraction_index()
 
-        t1.save_data(filename=filename, method='savez_compressed', add_name='')
+        t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
     def test_rectangle(self):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
-        x0 = np.linspace(-100 * um, 100 * um, 512)
-        z0 = np.linspace(0 * um, 200 * um, 512)
+        x0 = np.linspace(-100 * um, 100 * um, 256)
+        z0 = np.linspace(0 * um, 200 * um, 256)
         wavelength = 0.6238 * um
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
@@ -459,15 +417,15 @@ class Test_Scalar_masks_XZ(object):
             refraction_index=1.5)
         t1.draw_refraction_index()
 
-        t1.save_data(filename=filename, method='savez_compressed', add_name='')
+        t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
     def test_slit(self):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
-        x0 = np.linspace(-100 * um, 100 * um, 512 * 4)
-        z0 = np.linspace(0 * um, 250 * um, 512 * 4)
+        x0 = np.linspace(-100 * um, 100 * um, 256 * 4)
+        z0 = np.linspace(0 * um, 250 * um, 256 * 4)
         wavelength = 0.6238 * um
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
@@ -482,15 +440,15 @@ class Test_Scalar_masks_XZ(object):
 
         t1.draw_refraction_index()
 
-        t1.save_data(filename=filename, method='savez_compressed', add_name='')
+        t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
     def test_sphere(self):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
-        x0 = np.linspace(-100 * um, 100 * um, 512)
-        z0 = np.linspace(0 * um, 200 * um, 512)
+        x0 = np.linspace(-100 * um, 100 * um, 256)
+        z0 = np.linspace(0 * um, 200 * um, 256)
         wavelength = 0.6238 * um
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
@@ -503,15 +461,15 @@ class Test_Scalar_masks_XZ(object):
 
         t1.draw_refraction_index()
 
-        t1.save_data(filename=filename, method='savez_compressed', add_name='')
+        t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
     def test_semi_sphere(self):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
-        x0 = np.linspace(-200 * um, 200 * um, 512)
-        z0 = np.linspace(-120 * um, 120 * um, 512)
+        x0 = np.linspace(-200 * um, 200 * um, 256)
+        z0 = np.linspace(-120 * um, 120 * um, 256)
         wavelength = .5 * um
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
@@ -524,7 +482,7 @@ class Test_Scalar_masks_XZ(object):
         t1.draw_refraction_index(
             draw_borders=True, min_incr=0.01, scale='equal')
 
-        t1.save_data(filename=filename, method='savez_compressed', add_name='')
+        t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
@@ -538,8 +496,8 @@ class Test_Scalar_masks_XZ(object):
 
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
-        x0 = np.linspace(-100 * um, 100 * um, 512)
-        z0 = np.linspace(0 * um, 200 * um, 512)
+        x0 = np.linspace(-100 * um, 100 * um, 256)
+        z0 = np.linspace(0 * um, 200 * um, 256)
         wavelength = 0.6238 * um
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
@@ -553,14 +511,14 @@ class Test_Scalar_masks_XZ(object):
             rotation_point=None)
         t1.draw_refraction_index()
 
-        t1.save_data(filename=filename, method='savez_compressed', add_name='')
+        t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
     def test_prism(self):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
-        x0 = np.linspace(-150 * um, 150 * um, 512)
+        x0 = np.linspace(-150 * um, 150 * um, 256)
         z0 = np.linspace(0 * um, 500 * um, 4096)
         wavelength = 2 * um
 
@@ -573,14 +531,14 @@ class Test_Scalar_masks_XZ(object):
             angle=90 * degrees)
         t1.draw_refraction_index()
 
-        t1.save_data(filename=filename, method='savez_compressed', add_name='')
+        t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
     def test_biprism(self):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
-        x0 = np.linspace(-100 * um, 100 * um, 512)
+        x0 = np.linspace(-100 * um, 100 * um, 256)
         z0 = np.linspace(-5 * um, 395 * um, 4096)
         wavelength = 4 * um
 
@@ -593,15 +551,15 @@ class Test_Scalar_masks_XZ(object):
             angle=0)
         t1.draw_refraction_index(draw_borders=True, scale='equal')
 
-        t1.save_data(filename=filename, method='savez_compressed', add_name='')
+        t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
     def test_ronchi_grating(self):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
-        x0 = np.linspace(-500 * um, 500 * um, 512)
-        z0 = np.linspace(0 * um, 1400 * um, 512)
+        x0 = np.linspace(-500 * um, 500 * um, 256)
+        z0 = np.linspace(0 * um, 1400 * um, 256)
         wavelength = 0.5 * um
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
@@ -620,7 +578,7 @@ class Test_Scalar_masks_XZ(object):
 
         t1.draw_refraction_index()
 
-        t1.save_data(filename=filename, method='savez_compressed', add_name='')
+        t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
@@ -631,8 +589,8 @@ class Test_Scalar_masks_XZ(object):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
 
-        x0 = np.linspace(-500 * um, 500 * um, 512)
-        z0 = np.linspace(0 * um, 400 * um, 512)
+        x0 = np.linspace(-500 * um, 500 * um, 256)
+        z0 = np.linspace(0 * um, 400 * um, 256)
         wavelength = .55 * um
 
         t0 = Scalar_mask_X(x=x0, wavelength=wavelength)
@@ -650,15 +608,15 @@ class Test_Scalar_masks_XZ(object):
 
         t2.draw_refraction_index(draw_borders=False)
 
-        t2.save_data(filename=filename, method='savez_compressed', add_name='')
+        t2.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
     def test_sine_grating(self):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
-        x0 = np.linspace(-250 * um, 250 * um, 512)
-        z0 = np.linspace(0 * um, 1000 * um, 512)
+        x0 = np.linspace(-250 * um, 250 * um, 256)
+        z0 = np.linspace(0 * um, 1000 * um, 256)
         wavelength = 0.6238 * um
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
@@ -675,15 +633,15 @@ class Test_Scalar_masks_XZ(object):
 
         t1.draw_refraction_index()
 
-        t1.save_data(filename=filename, method='savez_compressed', add_name='')
+        t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
     def test_probe(self):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
-        x0 = np.linspace(-12 * um, 12 * um, 512)
-        z0 = np.linspace(0 * um, 500 * um, 512)
+        x0 = np.linspace(-12 * um, 12 * um, 256)
+        z0 = np.linspace(0 * um, 500 * um, 256)
         wavelength = .6 * um
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
@@ -696,15 +654,15 @@ class Test_Scalar_masks_XZ(object):
 
         t1.draw_refraction_index()
 
-        t1.save_data(filename=filename, method='savez_compressed', add_name='')
+        t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
     def test_lens_plane_convergent(self):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
-        x0 = np.linspace(-100 * um, 100 * um, 512)
-        z0 = np.linspace(-100 * um, 200 * um, 512)
+        x0 = np.linspace(-100 * um, 100 * um, 256)
+        z0 = np.linspace(-100 * um, 200 * um, 256)
         wavelength = 0.6238 * um
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
@@ -720,15 +678,15 @@ class Test_Scalar_masks_XZ(object):
         print("focus distance f={} um".format(focal))
         t1.draw_refraction_index(scale='equal')
 
-        t1.save_data(filename=filename, method='savez_compressed', add_name='')
+        t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
     def test_lens_convergent(self):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
-        x0 = np.linspace(-200 * um, 200 * um, 512)
-        z0 = np.linspace(-100 * um, 600 * um, 512)
+        x0 = np.linspace(-200 * um, 200 * um, 256)
+        z0 = np.linspace(-100 * um, 600 * um, 256)
         wavelength = 0.6238 * um
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
@@ -744,15 +702,15 @@ class Test_Scalar_masks_XZ(object):
         print("focus distance f={} um".format(focal))
         t1.draw_refraction_index(scale='equal')
 
-        t1.save_data(filename=filename, method='savez_compressed', add_name='')
+        t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
     def test_lens_plane_divergent(self):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
-        x0 = np.linspace(-75 * um, 75 * um, 512)
-        z0 = np.linspace(-100 * um, 200 * um, 512)
+        x0 = np.linspace(-75 * um, 75 * um, 256)
+        z0 = np.linspace(-100 * um, 200 * um, 256)
         wavelength = 0.6238 * um
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
@@ -768,15 +726,15 @@ class Test_Scalar_masks_XZ(object):
         print("focus distance f={} um".format(focal))
         t1.draw_refraction_index(scale='equal')
 
-        t1.save_data(filename=filename, method='savez_compressed', add_name='')
+        t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
     def test_lens_divergent(self):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
-        x0 = np.linspace(-75 * um, 75 * um, 512)
-        z0 = np.linspace(-50 * um, 250 * um, 512)
+        x0 = np.linspace(-75 * um, 75 * um, 256)
+        z0 = np.linspace(-50 * um, 250 * um, 256)
         wavelength = 0.6238 * um
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
@@ -792,15 +750,15 @@ class Test_Scalar_masks_XZ(object):
         print("focus distance f={} um".format(focal))
         t1.draw_refraction_index(scale='equal')
 
-        t1.save_data(filename=filename, method='savez_compressed', add_name='')
+        t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
 
     def test_rough_sheet(self):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
-        x0 = np.linspace(-150 * um, 150 * um, 512)
-        z0 = np.linspace(-150 * um, 150 * um, 512)
+        x0 = np.linspace(-150 * um, 150 * um, 256)
+        z0 = np.linspace(-150 * um, 150 * um, 256)
         wavelength = 0.6238 * um
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
@@ -814,6 +772,6 @@ class Test_Scalar_masks_XZ(object):
             rotation_point=None)
         t1.draw_refraction_index()
 
-        t1.save_data(filename=filename, method='savez_compressed', add_name='')
+        t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
         assert True
