@@ -7,8 +7,7 @@ import datetime
 import os
 import sys
 
-from diffractio import degrees, mm, nm, no_date, np, plt, sp, um
-from diffractio.scalar_fields_XY import Scalar_field_XY
+from diffractio import degrees, mm, no_date, np, plt, um
 from diffractio.scalar_masks_XY import Scalar_mask_XY
 from diffractio.scalar_sources_XY import Scalar_source_XY
 from diffractio.utils_math import nearest2
@@ -39,10 +38,9 @@ class Test_Scalar_sources_XY(object):
         npixels = 256
 
         # Generación de la clase
-        u = Scalar_source_XY(
-            x=np.linspace(-length / 2, length / 2, npixels),
-            y=np.linspace(-length / 2, length / 2, npixels),
-            wavelength=0.6328 * um)
+        u = Scalar_source_XY(x=np.linspace(-length / 2, length / 2, npixels),
+                             y=np.linspace(-length / 2, length / 2, npixels),
+                             wavelength=0.6328 * um)
 
         # carga de la onda plana
         u.plane_wave(phi=2 * degrees, theta=5 * degrees)
@@ -50,7 +48,7 @@ class Test_Scalar_sources_XY(object):
         # draw y guardar
         u.draw(kind='phase')
 
-        u.save_data(filename=filename, method='savez_compressed')
+        u.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -71,18 +69,17 @@ class Test_Scalar_sources_XY(object):
         u = Scalar_source_XY(x=x0, y=y0, wavelength=wavelength0)
 
         # carga del haz gaussiano
-        u.gauss_beam(
-            A=1,
-            r0=(0 * um, 0 * um),
-            z0=0,
-            w0=(25 * um, 25 * um),
-            phi=2 * degrees,
-            theta=5 * degrees)
+        u.gauss_beam(A=1,
+                     r0=(0 * um, 0 * um),
+                     z0=0,
+                     w0=(25 * um, 25 * um),
+                     phi=2 * degrees,
+                     theta=5 * degrees)
 
         # draw y guardar
         u.draw(kind='field')
 
-        u.save_data(filename=filename, method='savez_compressed')
+        u.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -103,13 +100,16 @@ class Test_Scalar_sources_XY(object):
         u = Scalar_source_XY(x=x0, y=y0, wavelength=wavelength0)
 
         # carga de la onda esferica
-        u.spherical_wave(
-            A=1, r0=(0 * um, 0 * um), z0=-5 * mm, radius=300 * um, mask=True)
+        u.spherical_wave(A=1,
+                         r0=(0 * um, 0 * um),
+                         z0=-5 * mm,
+                         radius=300 * um,
+                         mask=True)
 
         # draw la onda esferica
         u.draw(kind='field', normalize='maximum')
 
-        u.save_data(filename=filename, method='savez_compressed')
+        u.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -130,20 +130,18 @@ class Test_Scalar_sources_XY(object):
         u = Scalar_source_XY(x=x0, y=y0, wavelength=wavelength0)
 
         # carga de la onda esferica
-        u.spherical_wave(
-            A=1,
-            r0=(0 * um, 0 * um),
-            z0=-25.0 * mm,
-            radius=1300 * um,
-            mask=False)
+        u.spherical_wave(A=1,
+                         r0=(0 * um, 0 * um),
+                         z0=-25.0 * mm,
+                         radius=1300 * um,
+                         mask=False)
 
         t = Scalar_mask_XY(x0, y0, wavelength0)
-        t.lens(
-            r0=(0, 0),
-            radius=(300 * um, 300 * um),
-            focal=(25 * mm, 25 * mm),
-            angle=0,
-            mask=False)
+        t.lens(r0=(0, 0),
+               radius=(300 * um, 300 * um),
+               focal=(25 * mm, 25 * mm),
+               angle=0,
+               mask=False)
         u_salida = u * t
         u.draw(kind='field')
         t.draw(kind='field')
@@ -151,7 +149,7 @@ class Test_Scalar_sources_XY(object):
         # draw la onda esferica
         u_salida.draw(kind='field', normalize='maximum')
 
-        u.save_data(filename=filename, method='savez_compressed')
+        u.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -175,22 +173,19 @@ class Test_Scalar_sources_XY(object):
         u = Scalar_source_XY(x=x0, y=y0, wavelength=wavelength0)
 
         # carga del vortex_beam
-        u.vortex_beam(r0=(0, 0), w0=250 * um, m=m)
+        u.vortex_beam(A=1, r0=(0, 0), w0=250 * um, m=m)
 
         # draw el vortex_beam
         title = '$m_{vortice}= %d$' % (m)
         u.draw(kind='field', title=title)
 
-        u.save_data(filename=filename, method='savez_compressed')
+        u.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
     def test_vortices(self):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
-        """
-        Generación de varios haces de Laguerre
-        """
 
         # tamaño de la matrix
         M = 5
@@ -203,15 +198,11 @@ class Test_Scalar_sources_XY(object):
         u = Scalar_source_XY(x=x0, y=y0, wavelength=wavelength0)
 
         # Dos drawings, uno para la amplitude y otro para phase
-        ID1 = plt.figure(figsize=(10, 4.5))
+        plt.figure(figsize=(10, 4.5))
         plt.suptitle("$Vortices$", fontsize=20)
 
-        # Generación de la clase
-
-        # Doble bucle for para ubicar en el drawing N*K haces de Laguerre
         for m in range(M):
-            # carga del vórtice
-            u.vortex_beam(r0=(0 * um, 0 * um), w0=100 * um, m=m)
+            u.vortex_beam(A=1, r0=(0 * um, 0 * um), w0=100 * um, m=m)
 
             # carga de los drawings
             title = "(%d)" % (m)
@@ -226,7 +217,7 @@ class Test_Scalar_sources_XY(object):
             h2 = plt.imshow(np.angle(u.u))
             h2.set_cmap("seismic")
 
-        u.save_data(filename=filename, method='savez_compressed')
+        u.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -251,22 +242,22 @@ class Test_Scalar_sources_XY(object):
         u = Scalar_source_XY(x=x0, y=y0, wavelength=wavelength0)
 
         # carga del haz de Laguerre
-        u.laguerre_beam(
-            p=N, l=K, r0=(0 * um, 0 * um), w0=100 * um, z=0.01 * um)
+        u.laguerre_beam(A=1, n=N, l=K, r0=(0 * um, 0 * um),
+                        w0=100 * um,  z=0.01 * um, z0=0)
 
         # drawing
         title = r'$n=%d, k=%d$' % (N, K)
         u.draw(kind='field', title=title)
 
-        u.save_data(filename=filename, method='savez_compressed')
+        u.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
-    def test_laguerre(self):
+    def test_num_data(self):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
         """
-        Generación de varios haces de Laguerre
+        Generación de varios haces de num_data = 256
         """
 
         # tamaño de la matrix
@@ -288,15 +279,14 @@ class Test_Scalar_sources_XY(object):
 
         # Generación de la clase
 
-        # Doble bucle for para ubicar en el drawing N*K haces de Laguerre
         for n in range(N + 1):
             for k in range(K + 1):
+                u.laguerre_beam(A=1, n=n,
+                                l=k,
+                                r0=(0 * um, 0 * um),
+                                w0=100 * um,
+                                z=0.01 * um, z0=0)
 
-                # carga del haz de Laguerre
-                u.laguerre_beam(
-                    p=n, l=k, r0=(0 * um, 0 * um), w0=100 * um, z=0.01 * um)
-
-                # carga de los drawings
                 title = "(%d,%d)" % (n, k)
                 plt.figure(ID1.number)
                 plt.subplot(N + 1, K + 1, (N + 1) * (k) + n + 1)
@@ -315,7 +305,7 @@ class Test_Scalar_sources_XY(object):
         plt.figure(ID1.number)
         plt.figure(ID2.number)
 
-        u.save_data(filename=filename, method='savez_compressed')
+        u.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -332,11 +322,16 @@ class Test_Scalar_sources_XY(object):
         u = Scalar_source_XY(x=x0, y=y0, wavelength=wavelength0)
 
         # u.hermite_gauss_beam(I0=1, w=100*um, n = [0,0,1,1,3],     m =[0,1,0,1,3],  c_mn=[1,1,1,1,1])
-        u.hermite_gauss_beam(
-            A=1, r0=(0, 0), w0=100 * um, n=[1], m=[1], c_mn=[1])
+        u.hermite_gauss_beam(A=1,
+                             r0=(0, 0),
+                             w0=100 * um,
+                             n=1,
+                             m=1,
+                             z=0,
+                             z0=(0, 0))
         u.draw(kind='intensity')
 
-        u.save_data(filename=filename, method='savez_compressed')
+        u.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -360,11 +355,16 @@ class Test_Scalar_sources_XY(object):
         # creación del u
         u = Scalar_source_XY(x=x0, y=y0, wavelength=wavelength0)
 
-        u.zernike_beam(
-            A=1, r0=(0, 0), radius=length / 2, n=N, m=M, c_nm=c_nm, mask=True)
+        u.zernike_beam(A=1,
+                       r0=(0, 0),
+                       radius=length / 2,
+                       n=N,
+                       m=M,
+                       c_nm=c_nm,
+                       mask=True)
         u.draw(kind='field')
 
-        u.save_data(filename=filename, method='savez_compressed')
+        u.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -391,21 +391,18 @@ class Test_Scalar_sources_XY(object):
         # Generación de la clase
         u = Scalar_source_XY(x=x0, y=y0, wavelength=wavelength0)
 
-        # Doble bucle for para ubicar en el drawing N*K haces de Laguerre
         for n in range(0, N + 1):
             pos = 0
             for m in range(-n, n + 1, 2):
                 pos = pos + 1
 
-                # carga del haz de Laguerre
-                u.zernike_beam(
-                    A=1,
-                    r0=(0, 0),
-                    radius=length / 2,
-                    n=np.array([n]),
-                    m=np.array([m]),
-                    c_nm=np.array([1]),
-                    mask=True)
+                u.zernike_beam(A=1,
+                               r0=(0, 0),
+                               radius=length / 2,
+                               n=np.array([n]),
+                               m=np.array([m]),
+                               c_nm=np.array([1]),
+                               mask=True)
 
                 # carga de los drawings
                 title = "(%d,%d)" % (n, m)
@@ -416,7 +413,7 @@ class Test_Scalar_sources_XY(object):
                 plt.clim(vmin=-np.pi, vmax=np.pi)
                 h2.set_cmap("seismic")
 
-        u.save_data(filename=filename, method='savez_compressed')
+        u.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -429,11 +426,12 @@ class Test_Scalar_sources_XY(object):
         wavelength = 0.6328 * um
 
         u0 = Scalar_source_XY(x=x0, y=y0, wavelength=wavelength)
-        u0.plane_waves_several_inclined(
-            A=1, num_beams=(5, 5), max_angle=(5 * degrees, 180 * degrees))
+        u0.plane_waves_several_inclined(A=1,
+                                        num_beams=(5, 5),
+                                        max_angle=(5 * degrees, 180 * degrees))
         u0.draw(kind='field')
 
-        u0.save_data(filename=filename, method='savez_compressed')
+        u0.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -449,18 +447,17 @@ class Test_Scalar_sources_XY(object):
         wavelength = 0.6328 * um
 
         u0 = Scalar_source_XY(x=x0, y=y0, wavelength=wavelength)
-        u0.gauss_beams_several_parallel(
-            A=1,
-            num_beams=(5, 5),
-            w0=50 * um,
-            z0=0 * um,
-            r0=(0 * um, 0 * um),
-            r_range=(750 * um, 750 * um),
-            theta=0 * degrees,
-            phi=0 * degrees)
+        u0.gauss_beams_several_parallel(A=1,
+                                        num_beams=(5, 5),
+                                        w0=50 * um,
+                                        z0=0 * um,
+                                        r0=(0 * um, 0 * um),
+                                        r_range=(750 * um, 750 * um),
+                                        theta=0 * degrees,
+                                        phi=0 * degrees)
         u0.draw(kind='field')
 
-        u0.save_data(filename=filename, method='savez_compressed')
+        u0.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -473,16 +470,16 @@ class Test_Scalar_sources_XY(object):
         wavelength = 0.6328 * um
 
         u0 = Scalar_source_XY(x=x0, y=y0, wavelength=wavelength)
-        u0.gauss_beams_several_inclined(
-            A=1,
-            num_beams=(5, 5),
-            w0=250 * um,
-            r0=(0 * um, 0 * um),
-            z0=0 * um,
-            max_angle=(10 * degrees, 180 * degrees))
+        u0.gauss_beams_several_inclined(A=1,
+                                        num_beams=(5, 5),
+                                        w0=250 * um,
+                                        r0=(0 * um, 0 * um),
+                                        z0=0 * um,
+                                        max_angle=(10 * degrees,
+                                                   180 * degrees))
         u0.draw(kind='field')
 
-        u0.save_data(filename=filename, method='savez_compressed')
+        u0.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -498,25 +495,23 @@ class Test_Scalar_sources_XY(object):
         u1 = Scalar_source_XY(x=x0, y=y0, wavelength=wavelength0)
         u2 = Scalar_source_XY(x=x0, y=y0, wavelength=wavelength0)
 
-        u1.gauss_beam(
-            A=1,
-            r0=(0 * um, 0 * um),
-            w0=(500 * um, 500 * um),
-            z0=0 * um,
-            phi=2 * degrees,
-            theta=10 * degrees)
-        u2.gauss_beam(
-            A=1,
-            r0=(0 * um, 0 * um),
-            w0=(500 * um, 500 * um),
-            z0=0 * um,
-            phi=2 * degrees,
-            theta=-10 * degrees)
+        u1.gauss_beam(A=1,
+                      r0=(0 * um, 0 * um),
+                      w0=(500 * um, 500 * um),
+                      z0=0 * um,
+                      phi=2 * degrees,
+                      theta=10 * degrees)
+        u2.gauss_beam(A=1,
+                      r0=(0 * um, 0 * um),
+                      w0=(500 * um, 500 * um),
+                      z0=0 * um,
+                      phi=2 * degrees,
+                      theta=-10 * degrees)
 
         u3 = u1 + u2
         u3.draw(kind='intensity', title="$interferencias$")
 
-        u3.save_data(filename=filename, method='savez_compressed')
+        u3.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
 
@@ -545,10 +540,6 @@ class Test_Scalar_sources_XY(object):
         dist_sources_x = 2 * um
         dist_sources_y = 2 * um
 
-        # I create a empty matrix and I fill with dirac-deltas every dist_sources
-        X_mask = np.zeros_like(t_mask.X)
-        Y_mask = np.zeros_like(t_mask.X)
-
         pos_x = np.arange(x[0], x[-1], dist_sources_x)
         pos_y = np.arange(y[0], y[-1], dist_sources_y)
 
@@ -567,12 +558,15 @@ class Test_Scalar_sources_XY(object):
         u_final = Scalar_source_XY(x, y, wavelength)
         u_temp = Scalar_source_XY(x, y, wavelength)
         for x_i, y_i in zip(xpos, ypos):
-            u_temp.spherical_wave(
-                A=1, r0=(x_i, y_i), z0=z0, radius=10000 * um, mask=False)
+            u_temp.spherical_wave(A=1,
+                                  r0=(x_i, y_i),
+                                  z0=z0,
+                                  radius=10000 * um,
+                                  mask=False)
             u_final = u_final + u_temp
 
         u_final.draw(kind='field')
 
-        u_final.save_data(filename=filename, method='savez_compressed')
+        u_final.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
         assert True
